==> dtkgui-1%3A5.6.2.2-1-x86_64.pkg.tar.zst: usr/lib/cmake/DtkGui/DtkGuiConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was DtkGuiConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/DtkGui" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set_and_check(DtkGui_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/libdtk-5.6.2/DGui")
set_and_check(DtkGui_LIBRARY_DIRS "${PACKAGE_PREFIX_DIR}/lib")
set(DtkGui_TOOL_DIRS "${PACKAGE_PREFIX_DIR}/lib/libdtk-5.6.2/DGui/bin")

include(CMakeFindDependencyMacro)
find_dependency(DtkCore REQUIRED)
set(DtkGui_LIBRARIES dtkgui ${DtkCore_LIBRARIES})

include_directories("${DtkGui_INCLUDE_DIRS}")

check_required_components(DtkGui)

# Keep deprecated variables for compatibility
set(DTKGUI_INCLUDE_DIR ${DtkGui_INCLUDE_DIRS})
set(DTKGUI_TOOL_DIR ${DtkGui_TOOL_DIRS})

==> dtkgui-1%3A5.6.3-3-x86_64.pkg.tar.zst: usr/lib/cmake/DtkGui/DtkGuiConfig.cmake <==

####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was DtkGuiConfig.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/cmake/DtkGui" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

set_and_check(DtkGui_INCLUDE_DIRS "${PACKAGE_PREFIX_DIR}/include/libdtk-5.6.2/DGui")
set_and_check(DtkGui_LIBRARY_DIRS "${PACKAGE_PREFIX_DIR}/lib")
set(DtkGui_TOOL_DIRS "${PACKAGE_PREFIX_DIR}/lib/libdtk-5.6.2/DGui/bin")

include(CMakeFindDependencyMacro)
find_dependency(DtkCore REQUIRED)
find_library(DtkGui_LIBRARIES dtkgui ${DtkGui_LIBRARY_DIRS})
set(DtkGui_LIBRARIES ${DtkGui_LIBRARIES} ${DtkCore_LIBRARIES})

include_directories("${DtkGui_INCLUDE_DIRS}")

check_required_components(DtkGui)

# Keep deprecated variables for compatibility
set(DTKGUI_INCLUDE_DIR ${DtkGui_INCLUDE_DIRS})
set(DTKGUI_TOOL_DIR ${DtkGui_TOOL_DIRS})
